@@ -1492,7 +1492,7 @@ class MSSentinelApi:
                     id_list["cloudLogonSession"].append(id)
                     accumulator.append(current)
                 else:
-                    raise("Logon Session Duplicate")
+                    dbgPrint.warning("Logon Session Duplicate")
 
 
             elif current["type"] == "mailMessage":
